@@ -50,11 +50,6 @@ class KDECORATIONS2_EXPORT DecoratedClient : public QObject
      * The caption of the DecoratedClient.
      **/
     Q_PROPERTY(QString caption READ caption NOTIFY captionChanged)
-    /**
-     * The virtual desktop of the DecoratedClient. The special value @c -1 means on all
-     * desktops. For this prefer using the property onAllDesktops.
-     **/
-    Q_PROPERTY(int desktop READ desktop NOTIFY desktopChanged)
     /**
      * Whether the DecoratedClient is on all desktops or on just one.
      **/
@@ -174,7 +169,6 @@ public:
     ~DecoratedClient() override;
     bool isActive() const;
     QString caption() const;
-    int desktop() const;
     bool isOnAllDesktops() const;
     bool isShaded() const;
     QIcon icon() const;
@@ -204,7 +198,7 @@ public:
     int height() const;
     QSize size() const;
 
-    QPointer<Decoration> decoration() const;
+    Decoration *decoration() const;
     QPalette palette() const;
     /**
      * Used to get colors in QPalette.
@@ -244,7 +238,6 @@ public:
 Q_SIGNALS:
     void activeChanged(bool);
     void captionChanged(QString);
-    void desktopChanged(int);
     void onAllDesktopsChanged(bool);
     void shadedChanged(bool);
     void iconChanged(QIcon);
